@@ -24,6 +24,8 @@
 # along with PLplot; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
+use strict;
+use warnings;
 use PDL;
 use PDL::Graphics::PLplot;
 
